@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::SecurityHeader;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub register {
     my ($self, $app, $headers) = @_;
@@ -41,7 +41,7 @@ sub register {
 
     my %headers_default = (
         'Referrer-Policy'           => "",
-        'Strict-Transport-Security' => 31536000,
+        'Strict-Transport-Security' => "max-age=31536000",
         'X-Content-Type-Options'    => "nosniff",
         'X-Xss-Protection'          => '1; mode=block',
         'X-Frame-Options'           => 'DENY',
@@ -168,7 +168,7 @@ Mojolicious::Plugin::SecurityHeader
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
